@echo Install filter driver in system
@echo Usage: Install [device name]
@echo Important: default device name is "Lecroy Front Panel Device" 
@echo but might be different for your scope.

@set filename=ZtiLecroyFPanelFix.sys
@set filtername=ZtiLecroyFPanelFix
@set devname=Lecroy Front Panel Device
@if not "%~1"=="" set devname="%~1"
@set driverfile=%windir%\system32\drivers\%filename%
@set filtersvc=HKLM\SYSTEM\CurrentControlSet\Services\%filtername%

@echo.
@echo checking privilege elevation...
"%SYSTEMROOT%\system32\cacls.exe" "%SYSTEMROOT%\system32\config\system" >nul 2>&1
@if not %errorlevel%==0 (
  @echo ===== ERROR: insufficient rights =====
  @echo please run as administrator
  @pause
  goto :eof
)

@echo.
@echo installing filter driver file...
@if exist %driverfile% @echo replacing existing driver file...
@if not exist "%~dp0\%filename%" (
  @echo ===== ERROR =====
  @echo %filename% not existing in local directory.
  @pause
  goto :eof
)
copy "%~dp0\%filename%" %driverfile%
@if not exist %driverfile% (
  @echo ===== ERROR =====
  @echo %filename% not existing in driver directory ^(probably copy error^).
  @pause
  goto :eof
)
@echo filter driver file %driverfile% installed.

@echo.
@echo registering filter driver service...
@if not exist "%~dp0\%filtername%-driver.reg" (
  @echo ===== ERROR =====
  @echo %filtername%-driver.reg not existing in local directory.
  @pause
  goto :eof
)
regedit /s "%~dp0\%filtername%-driver.reg"
reg query %filtersvc% /v ImagePath
@if errorlevel 1 (
  @echo ===== ERROR =====
  @echo filter driver service not registered in CurrentControlSet\Services\%filtername%
  @echo please register with %filtername%-driver.reg
  @pause
  goto :eof
)
@echo filter driver service %filtername% probably installed.

@echo install filter driver...
"%~dp0\Filtject.exe" "%devname%" %filtername% -Add
"%~dp0\Filtject.exe" "%devname%" %filtername% -Check
@if errorlevel 1 (
  @echo ===== ERROR =====
  @echo filter driver not in device's driver stack ^(%devname%^)
  @echo please add filter with Filtject -add "%devname%" %filtername%
  @pause
  goto :eof
)
@echo filter driver service %filtername% is installed.

@echo.
@echo ===== Done =====
@echo please ensure %devname% is correct.
@echo stop device and restart it in device manager.
@echo then check if driver is loaded in device manager:
@echo - open device manager, show hidden devices
@echo - locate Data Acquisition Devices, Lecroy Front Panel Device
@echo - check if device is working properly
@echo - device properties ^> driver ^> details
@echo - ZtiLecroyFPanelFix has to be in list of drivers.
pause